==> tap4j-1.3-sources.jar: br/eti/kinoshita/tap4j/model/AbstractTapElementDiagnostic.java <==
/*
 * The MIT License
 *
 * Copyright (c) <2010> <Bruno P. Kinoshita>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package br.eti.kinoshita.tap4j.model;

import java.util.Map;


/**
 * TAP Element that supports diagnostic information.
 * 
 * @author Bruno P. Kinoshita - http://www.kinoshita.eti.br
 * @since 1.0
 */
public abstract class AbstractTapElementDiagnostic 
implements TapElement
{
	
	/**
	 * Iterable object returned by snakeyaml.
	 */
	protected Map<String, Object> diagnostic = null;
	
	/* (non-Javadoc)
	 * @see br.eti.kinoshita.tap4j.model.TapElement#getDiagnostic()
	 */
	public Map<String, Object> getDiagnostic() 
	{
		return this.diagnostic;
	}
	
	/* (non-Javadoc)
	 * @see br.eti.kinoshita.tap4j.model.TapElement#setDiagnostic(java.lang.Iterable)
	 */
	public void setDiagnostic(Map<String, Object> diagnostic) 
	{
		this.diagnostic = diagnostic;
	}
		
}

==> tap4j-1.4-sources.jar: br/eti/kinoshita/tap4j/model/AbstractTapElementDiagnostic.java <==
/*
 * The MIT License
 *
 * Copyright (c) <2010> <Bruno P. Kinoshita>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package br.eti.kinoshita.tap4j.model;

import java.util.LinkedHashMap;
import java.util.Map;


/**
 * TAP Element that supports diagnostic information.
 * 
 * @author Bruno P. Kinoshita - http://www.kinoshita.eti.br
 * @since 1.0
 */
public abstract class AbstractTapElementDiagnostic 
implements TapElement
{
	
	/**
	 * Iterable object returned by snakeyaml.
	 */
	protected Map<String, Object> diagnostic = new LinkedHashMap<String, Object>();
	
	/* (non-Javadoc)
	 * @see br.eti.kinoshita.tap4j.model.TapElement#getDiagnostic()
	 */
	public Map<String, Object> getDiagnostic() 
	{
		return this.diagnostic;
	}
	
	/* (non-Javadoc)
	 * @see br.eti.kinoshita.tap4j.model.TapElement#setDiagnostic(java.lang.Iterable)
	 */
	public void setDiagnostic(Map<String, Object> diagnostic) 
	{
		this.diagnostic = diagnostic;
	}
		
}
